package com.yaohun.aurechargedata.data;

import com.yaohun.aurechargedata.util.TimeType;
import org.bukkit.configuration.ConfigurationSection;

import java.util.HashMap;

public class PlayerData {

    private String name;  // 玩家名称
    private HashMap<TimeType, Integer> valueMap;  // 存储时间类型和对应值的映射

    // 构造函数，从配置节中加载玩家数据
    public PlayerData(String name, ConfigurationSection section) {
        this.name = name;  // 设置玩家名称
        this.valueMap = new HashMap<>();  // 创建一个新的映射
        // 如果配置节不为空，则加载数据
        if (section != null) {
            // 遍历配置节中的所有键
            for (String dataKey : section.getKeys(false)) {
                int value = section.getInt(dataKey);  // 获取键对应的整数值
                // 根据键名将值存储到不同的时间类型中
                if (dataKey.equalsIgnoreCase("daydata")) {
                    valueMap.put(TimeType.Daily, value);  // 每日数据
                } else if (dataKey.equalsIgnoreCase("monthdata")) {
                    valueMap.put(TimeType.Monthly, value);  // 每月数据
                } else {
                    valueMap.put(TimeType.Annual, value);  // 年度数据
                }
            }
        }else{
            // 配置节为空时存入默认数据
            valueMap.put(TimeType.Daily, 0);
            valueMap.put(TimeType.Monthly, 0);
            valueMap.put(TimeType.Annual, 0);
        }
    }

    // 获取玩家名称
    public String getName() {
        return name;
    }

    // 根据时间类型获取对应的值，如果值不存在返回 -1
    public int getValueData(TimeType timeType) {
        return valueMap.getOrDefault(timeType, -1);
    }

    // 设置特定时间类型的值
    public void setValueData(TimeType timeType, Integer amount) {
        valueMap.put(timeType, amount);
    }

    // 增加特定时间类型的值
    public void addValueData(TimeType timeType, Integer amount) {
        Integer currentValue = valueMap.getOrDefault(timeType, 0);
        int newAmount = currentValue + amount;
        valueMap.put(timeType, newAmount);
    }

    public HashMap<TimeType, Integer> getValueMap() {
        return valueMap;
    }

    // 根据时间类型返回对应的数据键名
    public String getTimeToString(TimeType timeType) {
        if (timeType == TimeType.Daily) {
            return "daydata";  // 如果时间类型是每日，则返回对应的数据键名
        } else if (timeType == TimeType.Monthly) {
            return "monthdata";  // 如果时间类型是每月，则返回对应的数据键名
        }
        return "annualData";  // 默认情况下返回年度数据键名
    }

}
